@@ -147,18 +147,18 @@ GeometricalAnalysisTools::ErrorCode GeometricalAnalysisTools::ComputeCharactersi
 		)
 	{
 		//compute the right dimensional coef based on the expected output
-		double dimensionalCoef = 1.0;
+		ScalarType dimensionalCoef = 1.0f;
 		switch (static_cast<Density>(subOption))
 		{
 		case DENSITY_KNN:
 			assert(false);
-			dimensionalCoef = 1.0;
+			dimensionalCoef = 1.0f;
 			break;
 		case DENSITY_2D:
-			dimensionalCoef = M_PI * pow(kernelRadius, 2.0);
+			dimensionalCoef = static_cast<ScalarType>(M_PI * pow(kernelRadius, 2.0));
 			break;
 		case DENSITY_3D:
-			dimensionalCoef = s_UnitSphereVolume * pow(kernelRadius, 3.0);
+			dimensionalCoef = static_cast<ScalarType>(s_UnitSphereVolume * pow(kernelRadius, 3.0));
 			break;
 		default:
 			assert(false);
@@ -169,7 +169,7 @@ GeometricalAnalysisTools::ErrorCode GeometricalAnalysisTools::ComputeCharactersi
 		for (unsigned i = 0; i < numberOfPoints; ++i)
 		{
 			ScalarType s = cloud->getPointScalarValue(i);
-			s = static_cast<ScalarType>(dimensionalCoef * s);
+			s /= dimensionalCoef;
 			cloud->setPointScalarValue(i, s);
 		}
 	}
@@ -741,7 +741,7 @@ CCLib::SquareMatrixd GeometricalAnalysisTools::ComputeWeightedCrossCovarianceMat
 bool GeometricalAnalysisTools::RefineSphereLS(	GenericIndexedCloudPersist* cloud,
 												CCVector3& center,
 												PointCoordinateType& radius,
-												double minReltaiveCenterShift/*=1.0e-3*/)
+												double minRelativeCenterShift/*=1.0e-3*/)
 {
 	if (!cloud || cloud->size() < 5)
 	{
@@ -791,11 +791,11 @@ bool GeometricalAnalysisTools::RefineSphereLS(	GenericIndexedCloudPersist* cloud
 		CCVector3d c0 = c;
 		//deduce new center
 		c = G - derivatives * meanNorm;
-		double r = meanNorm;
+		radius = static_cast<PointCoordinateType>(meanNorm);
 
 		double shift = (c-c0).norm();
-		double relativeShift = shift / r;
-		if (relativeShift < minReltaiveCenterShift)
+		double relativeShift = shift / radius;
+		if (relativeShift < minRelativeCenterShift)
 			break;
 	}
 
@@ -903,10 +903,13 @@ GeometricalAnalysisTools::ErrorCode GeometricalAnalysisTools::DetectSphereRobust
 			PointCoordinateType error = (*cloud->getPoint(i) - thisCenter).norm() - thisRadius;
 			values[i] = error*error;
 		}
-		std::sort(values.begin(), values.end());
+		
+		const unsigned int	medianIndex = n / 2;
+
+		std::nth_element(values.begin(), values.begin() + medianIndex, values.end());
 
 		//the error is the median of the squared residuals
-		double error = values[n / 2];
+		double error = static_cast<double>(values[medianIndex]);
 
 		//we keep track of the solution with the least error
 		if (error < minError || minError < 0.0)
