@@ -610,7 +610,7 @@ void ccHObject::drawBB(CC_DRAW_CONTEXT& context, const ccColor::Rgb& col)
 	glFunc->glPushAttrib(GL_LINE_BIT);
 	glFunc->glLineWidth(1.0f);
 
-	switch (m_selectionBehavior)
+	switch (getSelectionBehavior())
 	{
 	case SELECTION_AA_BBOX:
 		getDisplayBB_recursive(true, m_currentDisplay).draw(context, col);
@@ -654,24 +654,25 @@ void ccHObject::drawNameIn3D(CC_DRAW_CONTEXT& context)
 		return;
 
 	//we display it in the 2D layer in fact!
-	ccBBox bBox = getBB_recursive();
-	if (!bBox.isValid())
-		return;
+	//ccBBox bBox = getBB_recursive();
+	//if (!bBox.isValid())
+	//	return;
 	
-	ccGLMatrix trans;
-	getAbsoluteGLTransformation(trans);
+	//ccGLMatrix trans;
+	//getAbsoluteGLTransformation(trans);
 
-	ccGLCameraParameters camera;
-	context.display->getGLCameraParameters(camera);
+	//ccGLCameraParameters camera;
+	//context.display->getGLCameraParameters(camera);
 
-	CCVector3 C = bBox.getCenter();
-	CCVector3d Q2D;
-	camera.project(C, Q2D);
+	//CCVector3 C = bBox.getCenter();
+	//CCVector3d Q2D;
+	//camera.project(C, Q2D);
 
+	
 	QFont font = context.display->getTextDisplayFont(); //takes rendering zoom into account!
 	context.display->displayText(	getName(),
-									static_cast<int>(Q2D.x),
-									static_cast<int>(Q2D.y),
+									static_cast<int>(m_nameIn3DPos.x),
+									static_cast<int>(m_nameIn3DPos.y),
 									ccGenericGLDisplay::ALIGN_HMIDDLE | ccGenericGLDisplay::ALIGN_VMIDDLE,
 									0.75f,
 									nullptr,
@@ -742,9 +743,28 @@ void ccHObject::draw(CC_DRAW_CONTEXT& context)
 	}
 
 	//draw name - container objects are not visible but can still show a name
-	if (m_currentDisplay == context.display && m_showNameIn3D && MACRO_Draw2D(context) && MACRO_Foreground(context) && !MACRO_DrawEntityNames(context))
+	if (m_currentDisplay == context.display && m_showNameIn3D && !MACRO_DrawEntityNames(context))
 	{
-		drawNameIn3D(context);
+		if (MACRO_Draw3D(context))
+		{
+			//we have to comute the 2D position during the 3D pass!
+			ccBBox bBox = getBB_recursive(true); //DGM: take the OpenGL features into account (as some entities are purely 'GL'!)
+			if (bBox.isValid())
+			{
+				ccGLCameraParameters camera;
+				glFunc->glGetIntegerv(GL_VIEWPORT, camera.viewport);
+				glFunc->glGetDoublev(GL_PROJECTION_MATRIX, camera.projectionMat.data());
+				glFunc->glGetDoublev(GL_MODELVIEW_MATRIX, camera.modelViewMat.data());
+
+				CCVector3 C = bBox.getCenter();
+				camera.project(C, m_nameIn3DPos);
+			}
+		}
+		else if (MACRO_Draw2D(context) && MACRO_Foreground(context))
+		{
+			//then we can display the name during the 2D pass
+			drawNameIn3D(context);
+		}
 	}
 
 	//draw entity's children
