@@ -345,7 +345,7 @@ bool ccRasterGrid::fillWith(	ccGenericPointCloud* cloud,
 				assert(!scalarFields[k].empty());
 
 				CCLib::ScalarField* sf = pc->getScalarField(static_cast<unsigned>(k));
-				assert(sf && pos < static_cast<int>(sf->currentSize()));
+				assert(sf && pos < scalarFields[k].size());
 
 				ScalarType sfValue = sf->getValue(n);
 
@@ -543,7 +543,7 @@ bool ccRasterGrid::fillWith(	ccGenericPointCloud* cloud,
 						const double& valB = rows[ P[1][1] ][ P[1][0] ].h;
 						const double& valC = rows[ P[2][1] ][ P[2][0] ].h;
 
-						int det = (P[1][1] - P[2][1])*(P[0][0] - P[2][0]) + (P[2][0] - P[1][0])*(P[0][1] - P[2][1]);
+						double det = static_cast<double>((P[1][1] - P[2][1])*(P[0][0] - P[2][0]) + (P[2][0] - P[1][0])*(P[0][1] - P[2][1]));
 
 						for (int j = yMin; j <= yMax; ++j)
 						{
@@ -573,9 +573,9 @@ bool ccRasterGrid::fillWith(	ccGenericPointCloud* cloud,
 									//can we interpolate?
 									if (inside)
 									{
-										double l1 = static_cast<double>((P[1][1] - P[2][1])*(i - P[2][0]) + (P[2][0] - P[1][0])*(j - P[2][1])) / det;
-										double l2 = static_cast<double>((P[2][1] - P[0][1])*(i - P[2][0]) + (P[0][0] - P[2][0])*(j - P[2][1])) / det;
-										double l3 = 1.0-l1-l2;
+										double l1 = ((P[1][1] - P[2][1])*(i - P[2][0]) + (P[2][0] - P[1][0])*(j - P[2][1])) / det;
+										double l2 = ((P[2][1] - P[0][1])*(i - P[2][0]) + (P[0][0] - P[2][0])*(j - P[2][1])) / det;
+										double l3 = 1.0 - l1 - l2;
 
 										row[i].h = l1 * valA + l2 * valB + l3 * valC;
 										assert(std::isfinite(row[i].h));
@@ -597,7 +597,8 @@ bool ccRasterGrid::fillWith(	ccGenericPointCloud* cloud,
 											const double& sfValA = gridSF[P[0][0] + P[0][1] * width];
 											const double& sfValB = gridSF[P[1][0] + P[1][1] * width];
 											const double& sfValC = gridSF[P[2][0] + P[2][1] * width];
-											gridSF[i + j*width] = l1 * sfValA + l2 * sfValB + l3 * sfValC;
+											assert(i + j * width < gridSF.size());
+											gridSF[i + j * width] = l1 * sfValA + l2 * sfValB + l3 * sfValC;
 										}
 									}
 								}
@@ -736,6 +737,12 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 	//and we may have to change some things aftewards (height, scalar fields, etc.)
 	if (resampleInputCloudXY)
 	{
+		if (!inputCloud)
+		{
+			ccLog::Warning("[Rasterize] Internal error: no input clouds specified (for resampling)");
+			assert(false);
+			return nullptr;
+		}
 		CCLib::ReferenceCloud refCloud(inputCloud);
 		if (!refCloud.reserve(nonEmptyCellCount))
 		{
@@ -904,6 +911,7 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 					Pf.u[outY] = static_cast<PointCoordinateType>(Py);
 					Pf.u[outZ] = static_cast<PointCoordinateType>(aCell->h);
 
+					assert(cloudGrid->size() < cloudGrid->capacity());
 					cloudGrid->addPoint(Pf);
 
 					if (interpolateColors)
@@ -917,18 +925,19 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 				}
 
 				//fill the associated SFs
+				assert(!resampleInputCloudXY || inputCloud);
+				assert(!resampleInputCloudXY || nonEmptyCellIndex < inputCloud->size()); //we can't be here if we have a fully resampled cloud! (resampleInputCloudXY implies that inputCloud is defined)
 				assert(exportedSFs.size() == exportedFields.size());
-				assert(!inputCloud || nonEmptyCellIndex < inputCloud->size()); //we can't be here if we have a fully resampled cloud!
-				for (size_t i = 0; i < exportedSFs.size(); ++i)
+				for (size_t k = 0; k < exportedSFs.size(); ++k)
 				{
-					CCLib::ScalarField* sf = exportedSFs[i];
+					CCLib::ScalarField* sf = exportedSFs[k];
 					if (!sf)
 					{
 						continue;
 					}
 
 					ScalarType sVal = NAN_VALUE;
-					switch (exportedFields[i])
+					switch (exportedFields[k])
 					{
 					case PER_CELL_HEIGHT:
 						sVal = static_cast<ScalarType>(aCell->h);
@@ -958,14 +967,32 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 					
 					if (resampleInputCloudXY)
 					{
-						sf->setValue(nonEmptyCellIndex, sVal);
+						if (aCell->nbPoints != 0)
+						{
+							//previously existing point
+							assert(nonEmptyCellIndex < inputCloud->size());
+							assert(nonEmptyCellIndex < sf->size());
+							sf->setValue(nonEmptyCellIndex, sVal);
+						}
+						else
+						{
+							//new point
+							assert(sf->size() < sf->capacity());
+							sf->addElement(sVal);
+						}
 					}
 					else
 					{
+						//new point
+						assert(sf->size() < sf->capacity());
 						sf->addElement(sVal);
 					}
 				}
-				++nonEmptyCellIndex;
+
+				if (aCell->nbPoints != 0)
+				{
+					++nonEmptyCellIndex;
+				}
 			}
 			else if (fillEmptyCells) //empty cell
 			{
@@ -977,6 +1004,7 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 					Pf.u[outY] = static_cast<PointCoordinateType>(Py);
 					Pf.u[outZ] = static_cast<PointCoordinateType>(emptyCellsHeight);
 					
+					assert(cloudGrid->size() < cloudGrid->capacity());
 					cloudGrid->addPoint(Pf);
 
 					if (interpolateColors)
@@ -986,22 +1014,25 @@ ccPointCloud* ccRasterGrid::convertToCloud(	const std::vector<ExportableFields>&
 				}
 
 				assert(exportedSFs.size() == exportedFields.size());
-				for (size_t i = 0; i < exportedSFs.size(); ++i)
+				for (size_t k = 0; k < exportedSFs.size(); ++k)
 				{
-					if (!exportedSFs[i])
+					CCLib::ScalarField* sf = exportedSFs[k];
+					if (!sf)
 					{
 						continue;
 					}
-					
-					if (exportedFields[i] == PER_CELL_HEIGHT)
+
+					if (exportedFields[k] == PER_CELL_HEIGHT)
 					{
 						//we set the point height to the default height
 						ScalarType s = static_cast<ScalarType>(emptyCellsHeight);
-						exportedSFs[i]->addElement(s);
+						assert(sf->size() < sf->capacity());
+						sf->addElement(s);
 					}
 					else
 					{
-						exportedSFs[i]->addElement(NAN_VALUE);
+						assert(sf->size() < sf->capacity());
+						sf->addElement(NAN_VALUE);
 					}
 				}
 			}
