@@ -470,7 +470,7 @@ CC_FILE_ERROR LASFilter::saveToFile(ccHObject* entity, const QString& filename,
 	writerOptions.add("scale_y", lasScale.y);
 	writerOptions.add("scale_z", lasScale.z);
 
-	writerOptions.add("filename", filename.toLocal8Bit().toStdString());
+	writerOptions.add("filename", filename.toStdString());
 	writerOptions.add("extra_dims", "all");
 
 	const QVariant minor_version_meta_data = theCloud->getMetaData(LAS_VERSION_MINOR_META_DATA);
@@ -478,9 +478,9 @@ CC_FILE_ERROR LASFilter::saveToFile(ccHObject* entity, const QString& filename,
 	{
 		bool ok = false;
 		int minor_version = minor_version_meta_data.toInt(&ok);
-		if (ok)
+		if (ok && minor_version != 0) // PDAL can read but not write LAS 1.0
 			writerOptions.add("minor_version", minor_version);
-		else
+		else if (!ok)
 			ccLog::Warning(QString("Could not convert minor_version to int"));
 	}
 	const QVariant point_format_meta_data = theCloud->getMetaData(LAS_POINT_FORMAT_META_DATA);
@@ -891,7 +891,7 @@ std::vector<ExtraDim> readExtraBytesVlr(LasHeader &header)
 CC_FILE_ERROR LASFilter::loadFile(const QString& filename, ccHObject& container, LoadParameters& parameters)
 {
 	Options las_opts;
-	las_opts.add("filename", filename.toLocal8Bit().toStdString());
+	las_opts.add("filename", filename.toStdString());
 
 	FixedPointTable t(100);
 	LasReader lasReader;
