@@ -159,6 +159,7 @@ ccCommandLineParser::ccCommandLineParser()
 	registerCommand(Command::Shared(new CommandOrientNormalsMST));
 	registerCommand(Command::Shared(new CommandSORFilter));
 	registerCommand(Command::Shared(new CommandSampleMesh));
+	registerCommand(Command::Shared(new CommandExtractVertices));
 	registerCommand(Command::Shared(new CommandCrossSection));
 	registerCommand(Command::Shared(new CommandCrop));
 	registerCommand(Command::Shared(new CommandCrop2D));
@@ -486,7 +487,7 @@ bool ccCommandLineParser::importFile(QString filename, FileIOFilter::Shared filt
 	//now look for the remaining clouds inside loaded DB
 	{
 		ccHObject::Container clouds;
-		db->filterChildren(clouds, false, CC_TYPES::POINT_CLOUD);
+		db->filterChildren(clouds, true, CC_TYPES::POINT_CLOUD);
 		size_t count = clouds.size();
 		for (size_t i = 0; i < count; ++i)
 		{
