@@ -70,6 +70,7 @@ ccRasterizeTool::ccRasterizeTool(ccGenericPointCloud* cloud, QWidget* parent/*=0
 
 	//force update
 	resampleOptionToggled(resampleCloudCheckBox->isChecked());
+	fillEmptyCellStrategyChanged(0);
 
 	connect(buttonBox,					SIGNAL(accepted()),					this,	SLOT(testAndAccept()));
 	connect(buttonBox,					SIGNAL(rejected()),					this,	SLOT(testAndReject()));
@@ -107,9 +108,18 @@ ccRasterizeTool::ccRasterizeTool(ccGenericPointCloud* cloud, QWidget* parent/*=0
 
 	if (m_cloud)
 	{
-		cloudNameLabel->setText(m_cloud->getName());
-		pointCountLabel->setText(QString::number(m_cloud->size()));
-		interpolateSFFrame->setEnabled(cloud->hasScalarFields());
+		cloudNameLabel->setText(QStringLiteral("<b>%1</b> (%2 points)").arg(m_cloud->getName(), QLocale::system().toString(m_cloud->size())));
+		if (m_cloud->hasScalarFields())
+		{
+			interpolateSFCheckBox->setEnabled(true);
+			scalarFieldProjection->setEnabled(true);
+		}
+		else
+		{
+			interpolateSFCheckBox->setChecked(false);
+			interpolateSFCheckBox->setEnabled(false);
+			scalarFieldProjection->setEnabled(false);
+		}
 
 		//populate layer box
 		activeLayerComboBox->addItem(ccRasterGrid::GetDefaultFieldName(ccRasterGrid::PER_CELL_HEIGHT), QVariant(LAYER_HEIGHT));
@@ -137,6 +147,8 @@ ccRasterizeTool::ccRasterizeTool(ccGenericPointCloud* cloud, QWidget* parent/*=0
 	updateGridInfo();
 
 	gridIsUpToDate(false);
+	
+	resize( minimumSize() );
 }
 
 ccRasterizeTool::~ccRasterizeTool()
@@ -247,9 +259,9 @@ void ccRasterizeTool::projectionDirChanged(int dir)
 
 void ccRasterizeTool::activeLayerChanged(int layerIndex, bool autoRedraw/*=true*/)
 {
-	if (layerIndex != 0) //0 is always the cell height
+	if (activeLayerComboBox->itemData(layerIndex).toInt() == LAYER_SF && activeLayerComboBox->itemText(layerIndex) != HILLSHADE_FIELD_NAME)
 	{
-		interpolateSFCheckBox->setChecked(true);
+		interpolateSFCheckBox->setChecked(true); //force the choice of a SF projection strategy
 		interpolateSFCheckBox->setEnabled(false);
 		generateImagePushButton->setEnabled(false);
 		generateASCIIPushButton->setEnabled(false);
@@ -257,8 +269,9 @@ void ccRasterizeTool::activeLayerChanged(int layerIndex, bool autoRedraw/*=true*
 	}
 	else
 	{
+		//interpolateSFCheckBox->setChecked(false); //DGM: we can't force that, just let the user decide
+		interpolateSFCheckBox->setEnabled(m_cloud && m_cloud->hasScalarFields()); //we need SF fields!
 		generateImagePushButton->setEnabled(true);
-		interpolateSFCheckBox->setEnabled(true);
 		generateASCIIPushButton->setEnabled(true);
 		projectContoursOnAltCheckBox->setEnabled(false);
 	}
@@ -303,7 +316,7 @@ void ccRasterizeTool::activeLayerChanged(int layerIndex, bool autoRedraw/*=true*
 			}
 			else
 			{
-				gridLayerRangeLabel->setText("invalid layer?!");
+				gridLayerRangeLabel->setText("Layer not computed");
 				gridIsUpToDate(false);
 			}
 		}
@@ -319,8 +332,10 @@ void ccRasterizeTool::fillEmptyCellStrategyChanged(int)
 {
 	ccRasterGrid::EmptyCellFillOption fillEmptyCellsStrategy = getFillEmptyCellsStrategy(fillEmptyCellsComboBox);
 
-	emptyValueDoubleSpinBox->setEnabled(	fillEmptyCellsStrategy == ccRasterGrid::FILL_CUSTOM_HEIGHT
-										||	fillEmptyCellsStrategy == ccRasterGrid::INTERPOLATE );
+	bool active = fillEmptyCellsStrategy == ccRasterGrid::FILL_CUSTOM_HEIGHT ||	fillEmptyCellsStrategy == ccRasterGrid::INTERPOLATE;
+	
+	emptyValueDoubleSpinBox->setEnabled( active );
+	emptyValueDoubleSpinBox->setVisible( active );
 	gridIsUpToDate(false);
 }
 
@@ -354,8 +369,10 @@ ccRasterGrid::ProjectionType ccRasterizeTool::getTypeOfProjection() const
 
 ccRasterGrid::ProjectionType ccRasterizeTool::getTypeOfSFInterpolation() const
 {
-	if (!interpolateSFFrame->isEnabled() || !interpolateSFCheckBox->isChecked())
+	if (/*!interpolateSFCheckBox->isEnabled() || */!interpolateSFCheckBox->isChecked()) //DGM: the check-box might be disabled to actually 'force' the user to choose a projection type
+	{
 		return ccRasterGrid::INVALID_PROJECTION_TYPE; //means that we don't want to keep SF values
+	}
 
 	switch (scalarFieldProjection->currentIndex())
 	{
@@ -609,7 +626,7 @@ void ccRasterizeTool::updateGridAndDisplay()
 			//but we may also have to compute the 'original SF(s)' layer(s)
 			QString activeLayerName = activeLayerComboBox->currentText();
 			m_rasterCloud = convertGridToCloud(	exportedFields,
-												/*interpolateSF=*/activeLayerIsSF,
+												/*interpolateSF=*/interpolateSF,
 												/*interpolateColors=*/activeLayerIsRGB,
 												/*copyHillshadeSF=*/false,
 												activeLayerName,
